pyxmpp2.streamevents

Package pyxmpp2 :: Module streamevents |
[hide private]

# Module streamevents

XMPP stream events.

Classes | [hide private]
| StreamEvent Base class for all stream events.
| AuthenticatedEvent Event raised after stream authentication is complete.
| AuthorizedEvent Event raised after stream authentication and authorization is complete.
| BindingResourceEvent Emitted when resource binding is initiated for the stream.
| ConnectedEvent Emitted after the stream socket is connected, just before the actual XMPP exchange happens.
| ConnectingEvent Emitted on TCP connection attempt.
| ConnectionAcceptedEvent Emitted when a new TCP connection is accepted.
| DisconnectedEvent Emitted when the stream is disconnected.
| GotFeaturesEvent Emitted when the stream features are received.
| ResolvingAddressEvent Emitted when staring to resolve an address (A or AAAA) DNS record for a hostname.
| ResolvingSRVEvent Emitted when staring to resolve an SRV DNS record for a domain.
| StreamConnectedEvent Emitted when the initial stream handshake (<stream:stream> tag exchange) is completed, before any authentication.
| TLSConnectingEvent Emitted when the TLS handshake starts.
| TLSConnectedEvent Emitted when the TLS layer has been established.
| StreamRestartedEvent Emitted after stream is restarted (<stream:stream> tag exchange) e.g.